==> ec2-0.9.1-sources.jar: software/amazon/awscdk/services/ec2/cloudformation/SubnetResource.java <==
package software.amazon.awscdk.services.ec2.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-subnet.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.5 (build 845cc48)", date = "2018-09-14T09:16:47.245Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.cloudformation.SubnetResource")
public class SubnetResource extends software.amazon.awscdk.Resource {
    protected SubnetResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ec2.cloudformation.SubnetResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::EC2::Subnet``.
     * @param parent the ``cdk.Construct`` this ``SubnetResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``SubnetResource``
     */
    public SubnetResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.cloudformation.SubnetResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.ec2.SubnetId getRef() {
        return this.jsiiGet("ref", software.amazon.awscdk.services.ec2.SubnetId.class);
    }

    /**
     * @cloudformation_attribute AvailabilityZone
     */
    public software.amazon.awscdk.services.ec2.SubnetAvailabilityZone getSubnetAvailabilityZone() {
        return this.jsiiGet("subnetAvailabilityZone", software.amazon.awscdk.services.ec2.SubnetAvailabilityZone.class);
    }

    /**
     * @cloudformation_attribute Ipv6CidrBlocks
     */
    public software.amazon.awscdk.services.ec2.SubnetIpv6CidrBlocks getSubnetIpv6CidrBlocks() {
        return this.jsiiGet("subnetIpv6CidrBlocks", software.amazon.awscdk.services.ec2.SubnetIpv6CidrBlocks.class);
    }

    /**
     * @cloudformation_attribute NetworkAclAssociationId
     */
    public software.amazon.awscdk.services.ec2.SubnetNetworkAclAssociationId getSubnetNetworkAclAssociationId() {
        return this.jsiiGet("subnetNetworkAclAssociationId", software.amazon.awscdk.services.ec2.SubnetNetworkAclAssociationId.class);
    }

    /**
     * @cloudformation_attribute VpcId
     */
    public software.amazon.awscdk.services.ec2.SubnetVpcId getSubnetVpcId() {
        return this.jsiiGet("subnetVpcId", software.amazon.awscdk.services.ec2.SubnetVpcId.class);
    }
}

==> ec2-0.10.0-sources.jar: software/amazon/awscdk/services/ec2/cloudformation/SubnetResource.java <==
package software.amazon.awscdk.services.ec2.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-subnet.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:45:19.084Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.cloudformation.SubnetResource")
public class SubnetResource extends software.amazon.awscdk.Resource {
    protected SubnetResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ec2.cloudformation.SubnetResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::EC2::Subnet``.
     * @param parent the ``cdk.Construct`` this ``SubnetResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``SubnetResource``
     */
    public SubnetResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.ec2.cloudformation.SubnetResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(@javax.annotation.Nullable final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(properties).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.ec2.cloudformation.SubnetResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.ec2.cloudformation.SubnetResourceProps.class);
    }

    /**
     * @cloudformation_attribute AvailabilityZone
     */
    public java.lang.String getSubnetAvailabilityZone() {
        return this.jsiiGet("subnetAvailabilityZone", java.lang.String.class);
    }

    public java.lang.String getSubnetId() {
        return this.jsiiGet("subnetId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute Ipv6CidrBlocks
     */
    public software.amazon.awscdk.services.ec2.SubnetIpv6CidrBlocks getSubnetIpv6CidrBlocks() {
        return this.jsiiGet("subnetIpv6CidrBlocks", software.amazon.awscdk.services.ec2.SubnetIpv6CidrBlocks.class);
    }

    /**
     * @cloudformation_attribute NetworkAclAssociationId
     */
    public java.lang.String getSubnetNetworkAclAssociationId() {
        return this.jsiiGet("subnetNetworkAclAssociationId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute VpcId
     */
    public java.lang.String getSubnetVpcId() {
        return this.jsiiGet("subnetVpcId", java.lang.String.class);
    }
}
